@@ -34,13 +34,15 @@ class Age():
 
         Arguments
         ---------
-        * `age`: `int` or `str`. If `int`, it should fall in `[-1, 000+]`,
-            where `000` in `000+` is set by `estime2.options.age.max` 
-            (`99` by default), and `000+` means "000 or over". For example, 
-            `-2` will return an error; both `100` and `101` will return 
-            `100+`. If str, one can type either an int like `'94'` (which 
-            will be initialized as the age `94`), or `'99+'` where it is 
-            then defined as the age `99+`.
+        * `age`: `int`, `str`, or `Age` itself. If `int`, it should fall in
+            `[-1, 000+]`, where `000` in `000+` is set by 
+            `estime2.options.age.max` (`99` by default), and `000+` means 
+            "000 or over". For example, `-2` will return an error; both 
+            `100` and `101` will return `100+`. If `str`, one can type 
+            either an int like `'94'` (which will be initialized as the age
+            `94`), or `'99+'` where it is then defined as the age `99+`. In
+            case of it is `Age`, then it is converted back to `str` and is
+            initialized again.
         '''
 
         age_min = -1
