@@ -11,23 +11,39 @@ import numpy as np
 
 def plot_correction(
     result_fix_issues: List, 
+    corrections_type: List,
+    corrections_from: List,
     num: Optional[int] = None, 
     age_range: Optional[List[int]] = None,
     alpha: float = .5
 ):
     '''
     Get the barplot of ages vs. `num`-th correction made in 
-    `result_fix_issues` filtered by `age_range`. Set `alpha` for 
+    `result_fix_issues` filtered by `age_range`. Provide more information 
+    about the selected correction in `result_fix_issues` via 
+    `corrections_type` and `corrections_from`. Set `alpha` for 
     transparency.
 
     Usage
     -----
-    `plot_correction(result_fix_issues, num[, age_range, alpha])`
+    `plot_correction(
+        result_fix_issues, 
+        corrections_type,
+        corrections_from,
+        num[, age_range, alpha]
+    )`
 
     Argument
     --------
     * `result_fix_issues`: a list; return value of 
-        `ProvPopTable.fix_issues(return_all_mods = True)`.
+        `ProvPopTable.fix_issues(return_all_mods = True)` or
+        `SubProvPopTable.fix_issues(return_all_mods = True)`.
+    * `corrections_type`: a list of `str` ('L', 'O', or 'P') of length 
+        `len(result_fix_issues) - 1`; a list specifying the type of each 
+        correction in `result_fix_issues`
+    * `corrections_from`: a list of `object`s of length
+        `len(result_fix_issues) - 1`; a list specifying the source
+        of each correction in `result_fix_issues`
     * `num`: an int, `None` by default; the order number of the correction 
         made. For example, `num = 3` means the function will display the
         3rd correction applied to the table. If left `None`, then the error
@@ -45,6 +61,8 @@ def plot_correction(
     age = poptbl.get_pop_groups()[1]
 
     c_to_work_with = result_fix_issues[num]
+    c_type = corrections_type[num - 1]
+    c_from = corrections_from[num - 1]
     p_sex = c_to_work_with.iloc[-1, :].values[0]
     comp_L = c_to_work_with.iloc[:, -1].name
     p_comp = comp_L[:-2]
@@ -67,8 +85,8 @@ def plot_correction(
         c_to_work_with[comp_L],
         alpha = alpha
     )
-    plt.suptitle(f"Corrections made at the correction number {num}")
-    plt.title(f"sex {p_sex} comp {p_comp}")
+    plt.suptitle(f"Corrections made at {p_comp}, correction number {num}")
+    plt.title(f"sex {p_sex} type {c_type} from {c_from}")
     plt.xlabel(f"{age}")
     plt.ylabel(f"Corrections in {p_comp}")
 
@@ -88,7 +106,7 @@ def plot_pop(
 
     Argument
     --------
-    * `poptbl`: a `ProvPopTable`
+    * `poptbl`: a `ProvPopTable` or `SubProvPopTable`
     * `sex`: an object, `None` by default; use only records having the same
         `sex` in `poptbl`. If `None`, then the function checks if `poptbl`
         has an unique `sex`. If it does, it uses that `sex`; otherwise, it
